pub struct Components { /* private fields */ }
Contains metadata for all the components in a world.

This can be obtained in a system by using the &Components system parameter.

world.add_system(|_: Receiver<E>, components: &Components| {});

Implementations

source

impl Components

source

pub fn get(&self, id: ComponentId) -> Option<&ComponentInfo>

Gets the ComponentInfo of the given component. Returns None if the ID is invalid.

source

pub fn get_by_index(&self, idx: ComponentIdx) -> Option<&ComponentInfo>

Gets the ComponentInfo for a component using its ComponentIdx. Returns None if the index is invalid.

source

pub fn get_by_type_id(&self, type_id: TypeId) -> Option<&ComponentInfo>

Gets the ComponentInfo for a component using its TypeId. Returns None if the TypeId does not map to a component.

source

pub fn contains(&self, id: ComponentId) -> bool

Does the given component exist in the world?

source

pub fn iter(&self) -> impl Iterator<Item = &ComponentInfo>

Returns an iterator over all component infos.