Struct evenio::component::RemoveComponent
source · pub struct RemoveComponent(pub ComponentId);Expand description
An event sent immediately before a component is removed from the world. Contains the ID of the component to be removed.
Tuple Fields
0: ComponentIdTrait Implementations
sourceimpl Clone for RemoveComponent
impl Clone for RemoveComponent
sourcefn clone(&self) -> RemoveComponent
fn clone(&self) -> RemoveComponent
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for RemoveComponent
impl Debug for RemoveComponent
sourceimpl Event for RemoveComponent
impl Event for RemoveComponent
sourceimpl Hash for RemoveComponent
impl Hash for RemoveComponent
sourceimpl Ord for RemoveComponent
impl Ord for RemoveComponent
sourcefn cmp(&self, other: &RemoveComponent) -> Ordering
fn cmp(&self, other: &RemoveComponent) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for RemoveComponent
impl PartialEq for RemoveComponent
sourcefn eq(&self, other: &RemoveComponent) -> bool
fn eq(&self, other: &RemoveComponent) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for RemoveComponent
impl PartialOrd for RemoveComponent
sourcefn partial_cmp(&self, other: &RemoveComponent) -> Option<Ordering>
fn partial_cmp(&self, other: &RemoveComponent) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Copy for RemoveComponent
impl Eq for RemoveComponent
impl StructuralPartialEq for RemoveComponent