pub struct EntityId(/* private fields */);Expand description
Lightweight identifier for an entity.
Entity identifiers are implemented using an index and a generation count. The generation count ensures that IDs from despawned entities are not reused by new entities.
An entity identifier is only meaningful in the World it was created
from. Attempting to use an entity ID in a different world will have
unexpected results.
Implementations
Sourceimpl EntityId
impl EntityId
Sourcepub const NULL: Self
pub const NULL: Self
The entity ID which never identifies a live entity. This is the default
value for EntityId.
Sourcepub const fn new(index: u32, generation: u32) -> Option<Self>
pub const fn new(index: u32, generation: u32) -> Option<Self>
Creates a new entity ID from an index and generation count. Returns
None if a valid ID is not formed.
Sourcepub const fn generation(self) -> u32
pub const fn generation(self) -> u32
Returns the generation count of this ID.