Struct evenio::event::Spawn

source ·
pub struct Spawn(pub EntityId);
An Event which signals the creation of an entity. Contains the EntityId of the new entity.

The event by itself has no additional effects, and cannot be used to spawn new entities. Use World::spawn or Sender::spawn instead.

Tuple Fields

0: EntityId