HandlerInfo

Struct HandlerInfo 

pub struct HandlerInfo(/* private fields */);
Metadata for a handler.

Implementations

Source

impl HandlerInfo

pub fn name(&self) -> &str

Gets the name of the handler.

This name is intended for debugging purposes and should not be relied upon for correctness.

pub fn id(&self) -> HandlerId

Gets the ID of this handler.

pub fn type_id(&self) -> Option<TypeId>

Gets the TypeId of this handler, if any.

pub fn received_event(&self) -> EventId

Gets the EventId of the event this handler listens for.

pub fn received_event_access(&self) -> Access

Gets the handler’s Access to the event it listens for.

pub fn targeted_event_component_access(&self) -> Option<&ComponentAccess>

Gets the expression describing the handler’s targeted event query, or None if this handler is not targeted.

pub fn sent_global_events( &self, ) -> impl Iterator<Item = GlobalEventIdx> + Clone + Debug + '_

Returns an iterator over the set of global events this handler sends.

pub fn sent_targeted_events( &self, ) -> impl Iterator<Item = TargetedEventIdx> + Clone + Debug + '_

Returns an iterator over the set of targeted events this handler sends.

pub fn event_queue_access(&self) -> Access

Gets this handler’s Access to the event queue.

pub fn component_access(&self) -> &ComponentAccess

Gets the expression describing this handler’s access

pub fn archetype_filter(&self) -> &ComponentAccess

Returns the ComponentAccess used for matching archetypes.

pub fn referenced_components( &self, ) -> impl Iterator<Item = ComponentIdx> + Clone + Debug + '_

Gets the set of components referenced by this handler.

Referenced components are components used by the handler in any way. Used for cleanup when removing components.

pub fn references_component(&self, idx: ComponentIdx) -> bool

Does this handler reference the given component?

pub fn priority(&self) -> HandlerPriority

Gets the HandlerPriority of this handler.