pub struct Archetypes { /* private fields */ }Expand description
Contains all the Archetypes and their metadata for a world.
This can be obtained in a handler by using the &Archetypes handler
parameter.
world.add_handler(|_: Receiver<E>, archetypes: &Archetypes| {});Implementations
Sourceimpl Archetypes
impl Archetypes
Sourcepub fn empty(&self) -> &Archetype
pub fn empty(&self) -> &Archetype
Returns a reference to the empty archetype (The archetype with no components).
The empty archetype is always present, so this function is infallible.
Sourcepub fn get(&self, idx: ArchetypeIdx) -> Option<&Archetype>
pub fn get(&self, idx: ArchetypeIdx) -> Option<&Archetype>
Gets a reference to the archetype identified by the given
ArchetypeIdx. Returns None if the index is invalid.
Sourcepub fn get_by_components(
&self,
components: &[ComponentIdx],
) -> Option<&Archetype>
pub fn get_by_components( &self, components: &[ComponentIdx], ) -> Option<&Archetype>
Gets a reference to the archetype with the given set of components.
Returns None if there is no archetype with the given set of
components or the given ComponentIdx slice is not sorted and
deduplicated.