Struct evenio::component::Components
source · pub struct Components { /* private fields */ }Expand description
Contains metadata for all the components in a world.
This can be obtained in a system by using the &Components system
parameter.
world.add_system(|_: Receiver<E>, components: &Components| {});Implementations
sourceimpl Components
impl Components
sourcepub fn get(&self, id: ComponentId) -> Option<&ComponentInfo>
pub fn get(&self, id: ComponentId) -> Option<&ComponentInfo>
Gets the ComponentInfo of the given component. Returns None if the
ID is invalid.
sourcepub fn get_by_index(&self, idx: ComponentIdx) -> Option<&ComponentInfo>
pub fn get_by_index(&self, idx: ComponentIdx) -> Option<&ComponentInfo>
Gets the ComponentInfo for a component using its ComponentIdx.
Returns None if the index is invalid.
sourcepub fn get_by_type_id(&self, type_id: TypeId) -> Option<&ComponentInfo>
pub fn get_by_type_id(&self, type_id: TypeId) -> Option<&ComponentInfo>
Gets the ComponentInfo for a component using its TypeId. Returns
None if the TypeId does not map to a component.
sourcepub fn contains(&self, id: ComponentId) -> bool
pub fn contains(&self, id: ComponentId) -> bool
Does the given component exist in the world?
sourcepub fn iter(&self) -> impl Iterator<Item = &ComponentInfo>
pub fn iter(&self) -> impl Iterator<Item = &ComponentInfo>
Returns an iterator over all component infos.