pub struct Spawn(pub EntityId);Expand description
An Event which signals the creation of an entity. Contains the
EntityId of the new entity.
The event by itself has no additional effects, and cannot be used to spawn
new entities. Use World::spawn or Sender::spawn instead.
Tuple Fields
0: EntityIdTrait Implementations
sourceimpl Ord for Spawn
impl Ord for Spawn
sourceimpl PartialEq for Spawn
impl PartialEq for Spawn
sourceimpl PartialOrd for Spawn
impl PartialOrd for Spawn
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Copy for Spawn
impl Eq for Spawn
impl StructuralPartialEq for Spawn